# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).


## [Unreleased](https://github.com/tomdyson/wagtail-netlify/compare/v0.4...HEAD)

...

## [v0.4](https://github.com/tomdyson/wagtail-netlify/compare/v0.3...v0.4)

### Added

- support for generating redirects without deploying

## [v0.3](https://github.com/tomdyson/wagtail-netlify/compare/v0.2...v0.3)

### Added

- Netlify-cli 2.x compatibility #13
- Possibility to define custom deployments function #8

### Removed

- Netlify-cli 1.x compatibility #13

## [v0.2](https://github.com/tomdyson/wagtail-netlify/compare/v0.1...v0.2)

### Added

- Wagtail 2.0 compatibility #4

### Fixed

- Prevent modification of Deployment objects #2
- Prevent registration of Deployment modeladmin when the modeladmin app isn't installed #3

## [v0.1](https://github.com/tomdyson/wagtail-netlify/compare/f8f45701f43e28e238fc64aceea07dd1900343fc...v0.1)

Initial Release
